==> xnee-1.08.tar.gz: xnee-1.08/libxnee/include/libxnee/xnee_threshold.h <==
/*****
 *       Xnee's Not an Event Emulator                                
 *                                                                   
 * Xnee enables recording and replaying of X protocol data           
 *                                                                   
 *        Copyright (C) 1999, 2000, 2001, 2002, 2003 Henrik Sandklef                    
 *                                                                   
 * This program is free software; you can redistribute it and/or     
 * modify it under the terms of the GNU General Public License       
 * as published by the Free Software Foundation; either version 2    
 * of the License, or any later version.                             
 *                                                                   
 *                                                                   
 * This program is distributed in the hope that it will be useful,   
 * but WITHOUT ANY WARRANTY; without even the implied warranty of    
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     
 * GNU General Public License for more details.                      
 *                                                                   
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software       
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,            
 * MA  02111-1307, USA.                                              
 ****/


#include <X11/extensions/XTest.h>

#include "libxnee/xnee.h"
#include "libxnee/print.h"
#include "libxnee/xnee_record.h"
#include "libxnee/xnee_replay.h"
#include "libxnee/xnee_sem.h"
#include "libxnee/xnee_resolution.h"


int
xnee_set_max_threshold_str (xnee_data *xd, char *thresh_str);

int
xnee_set_min_threshold_str (xnee_data *xd, char *thresh_str);

int
xnee_set_tot_threshold_str (xnee_data *xd, char *thresh_str);

int
xnee_set_max_threshold (xnee_data *xd, int thresh);

int
xnee_set_min_threshold (xnee_data *xd, int thresh);

int
xnee_set_tot_threshold (xnee_data *xd, int thresh);


#define xnee_get_max_threshold(xd) xd->meta_data.sum_max_threshold

#define xnee_get_min_threshold(xd) xd->meta_data.sum_min_threshold

#define xnee_get_tot_threshold(xd) xd->meta_data.tot_diff_threshold



/* implemented as defines above
int
xnee_get_max_threshold (xnee_data *xd);

int
xnee_get_min_threshold (xnee_data *xd);

int
xnee_get_tot_threshold (xnee_data *xd);
*/

==> xnee_3.13.orig.tar.gz: xnee-3.13/libxnee/include/libxnee/xnee_threshold.h <==
/*****
 *       Xnee's Not an Event Emulator                                
 *                                                                   
 * Xnee enables recording and replaying of X protocol data           
 *                                                                   
 *        Copyright (C) 1999, 2000, 2001, 2002, 2003 Henrik Sandklef                    
 *                                                                   
 * This program is free software; you can redistribute it and/or     
 * modify it under the terms of the GNU General Public License       
 * as published by the Free Software Foundation; either version 3    
 * of the License, or any later version.                             
 *                                                                   
 *                                                                   
 * This program is distributed in the hope that it will be useful,   
 * but WITHOUT ANY WARRANTY; without even the implied warranty of    
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     
 * GNU General Public License for more details.                      
 *                                                                   
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software       
 * Foundation, Inc., 51 Franklin Street, Boston,            
 * MA  02110-1301, USA.                                              
 ****/

#ifndef XNEE_THRESHOLD_H
#define XNEE_THRESHOLD_H

#include "libxnee/xnee.h"

/* The headers have moved to xnee_setget.h */

#endif /* XNEE_THRESHOLD_H */
